@@ -1,5 +1,7 @@
 """Processing of systems."""
 
+from argparse import Namespace
+
 from homeinfotools.filetransfer.filetransfer import filetransfer
 from homeinfotools.multiprocessing import BaseWorker
 
@@ -10,6 +12,7 @@ __all__ = ['Worker']
 class Worker(BaseWorker):
     """Stored args and manager to process systems."""
 
-    def run(self, system: int) -> dict:
+    @staticmethod
+    def run(system: int, args: Namespace) -> dict:
         """Runs the worker."""
-        return {'rsync': filetransfer(system, self.args)}
+        return {'rsync': filetransfer(system, args)}
